@@ -3,7 +3,7 @@ import subprocess
 import logging
 
 import requests
-from requests import exceptions
+from requests import exceptions, Session
 
 from python_kemptech_api import utils
 from python_kemptech_api.api_xml import (
@@ -43,8 +43,8 @@ class HttpClient(object):
     endpoint = None
 
     def __init__(self, tls_version=utils.DEFAULT_TLS_VERSION):
-        self.tls_session = requests.Session()
-        self.tls_session.mount("http://", UseTlsAdapter(tls_version))
+        self._tls_session = Session()
+        self._tls_session.mount("http://", UseTlsAdapter(tls_version))
 
     def __enter__(self):
         return self
@@ -61,6 +61,7 @@ class HttpClient(object):
         :param rest_command: The command to run.
         :param parameters: dict containing parameters.
         :param file: Location of file to send.
+        :param headers: Optional headers to send.
         :return: The Status code of request and the response text body.
         """
 
@@ -71,16 +72,16 @@ class HttpClient(object):
         try:
             if file is not None:
                 with open(file, 'rb') as payload:
-                    response = self.tls_session.request(http_method, cmd_url,
-                                                        params=parameters,
-                                                        verify=False,
-                                                        data=payload,
-                                                        headers=headers)
+                    response = self._tls_session.request(http_method, cmd_url,
+                                                         params=parameters,
+                                                         verify=False,
+                                                         data=payload,
+                                                         headers=headers)
             else:
-                response = self.tls_session.request(http_method, cmd_url,
-                                                    params=parameters,
-                                                    timeout=5, verify=False,
-                                                    headers=headers)
+                response = self._tls_session.request(http_method, cmd_url,
+                                                     params=parameters,
+                                                     timeout=5, verify=False,
+                                                     headers=headers)
             if 400 < response.status_code < 500:
                 raise KempTechApiException(msg=response.text)
             else:
@@ -255,7 +256,7 @@ class LoadMaster(HttpClient):
         if is_sub_vs:
             response = self._get("/showvs", {"vs": service.get('MasterVSID')})
             data = get_data(response)
-            subvs_id_list, subvs_data = get_sub_vs_list_from_data(data)
+            subvs_data = get_sub_vs_list_from_data(data)[1]
             virt_serv = VirtualService(self.access_info, service.get('Index'),
                                        is_sub_vs=True)
             virt_serv.subvs_data = subvs_data[service.get('Index')]
@@ -341,7 +342,7 @@ class LoadMaster(HttpClient):
                                                            ip=self.ip_address,
                                                            port=self.port)
         try:
-            self.tls_session.get(url, verify=False, timeout=1)
+            self._tls_session.get(url, verify=False, timeout=1)
             return True
         except exceptions.RequestException:
             return False
@@ -431,8 +432,8 @@ class LoadMaster(HttpClient):
         file_name = "backups/{}.backup".format(self.ip_address)
 
         with open(file_name, 'wb') as file:
-            curl = ['curl', '-k', '--connect-timeout', '5', '{}/backup'.format(
-                    self.endpoint)]
+            curl = ['curl', '-k', '--connect-timeout', '5',
+                    '{}/backup'.format(self.endpoint)]
             subprocess.call(curl, stdout=file)
             file.seek(0, 2)
             if file.tell() == 0:
