@@ -1,6 +1,9 @@
+import requests
 from nose.tools import (assert_equal, assert_is_instance, assert_raises,
    assert_false, assert_in)
 
+from python_kemptech_api import api_xml
+
 try:
     import unittest.mock as mock
 except ImportError:
@@ -37,19 +40,23 @@ class Test_HttpClient_as_context_manager:
 class Test_HttpClient_do_request:
 
     def setup(self):
-        self.p_requests = patch.object(client, 'tls_session')
-        requests = self.p_requests.start()
+        self.p_Session = patch.object(client, 'Session')
+        Session = self.p_Session.start()
+        self.p_requests = patch.object(client, 'requests')
+        rquests = self.p_requests.start()
+        Session.return_value = rquests
 
         self.response = MagicMock()
         self.response.status_code = 200
         self.response.text = sentinel.response_text
-        self.request = requests.request
+        self.request = rquests.request
         self.request.return_value = self.response
 
         self.client = client.HttpClient()
         self.client.endpoint = 'ep/'
 
     def teardown(self):
+        self.p_Session.stop()
         self.p_requests.stop()
 
     def test_no_file_parameter_set(self):
@@ -134,10 +141,11 @@ class Test_LoadMaster:
             mock_endpoint.return_value =  "https://bal:2fourall@1.1.1.1:443/access"
 
         service= {'VSPort': 80,
-                        'Protocol': 'TCP',
-                        'VSAddress': '1.1.1.1'
-                        }
-        res = lm.build_virtual_service(service)
+                  'Protocol': 'TCP',
+                  'VSAddress': '1.1.1.1'}
+        with patch.object(api_xml, 'get_data') as get_data:
+            get_data.return_value = {}
+            res = lm.build_virtual_service(service, "not none")
         assert_is_instance(res, client.VirtualService)
 
 
