@@ -113,9 +113,11 @@ class Test_get_virtual_services:
         with patch.object(LoadMaster, 'build_virtual_service') as build_virtual_service:
             with patch.object(client, 'get_data') as get_data:
                 with patch.object(LoadMaster, '_get'):
-                    build_virtual_service.side_effect = sorted
+                    def sorted_wrap(kwargs, arbitrary):
+                        return sorted(kwargs)
+                    build_virtual_service.side_effect = sorted_wrap
                     get_data. return_value = {'VS': ['ba', 'ed']}
-                    res =  self.lm.get_virtual_services()
+                    res = self.lm.get_virtual_services()
         expected = [['a','b'], ['d','e']]
         assert_equal(res, expected)
 
